@@ -132,7 +132,7 @@ function task_install_source_deb_systemd {
 # Debian packaging during the 'install' phases.
 function task_install {
     install -d -m 0755 "${DESTDIR}${app_prefix}"
-    install -d -m 0755 "${DESTDIR}${app_data}"
+    install -d -m 0770 "${DESTDIR}${app_data}"
     install -m 0644 puppet-server-release.jar "${DESTDIR}${app_prefix}"
     install -m 0755 ext/ezbake-functions.sh "${DESTDIR}${app_prefix}"
     install -m 0644 ext/ezbake.manifest "${DESTDIR}${app_prefix}"
@@ -164,19 +164,24 @@ function task_install {
     install -d -m 0755 "${DESTDIR}${uxbindir}"
     ln -s "../server/apps/${real_name}/bin/${real_name}" "${DESTDIR}${uxbindir}/${real_name}"
     install -m 0755 ext/cli/irb "${DESTDIR}${app_prefix}/cli/apps/irb"
+    install -m 0755 ext/cli/start "${DESTDIR}${app_prefix}/cli/apps/start"
     install -m 0755 ext/cli/ruby "${DESTDIR}${app_prefix}/cli/apps/ruby"
+    install -m 0755 ext/cli/reload "${DESTDIR}${app_prefix}/cli/apps/reload"
     install -m 0755 ext/cli/foreground "${DESTDIR}${app_prefix}/cli/apps/foreground"
     install -m 0755 ext/cli/gem "${DESTDIR}${app_prefix}/cli/apps/gem"
+    install -m 0755 ext/cli/stop "${DESTDIR}${app_prefix}/cli/apps/stop"
     install -d -m 0755 "${DESTDIR}${rundir}"
     install -d -m 700 "${DESTDIR}${app_logdir}"
 }
 
 function task_install_redhat {
     task install
+    bash ./ext/build-scripts/install-vendored-gems.sh
 }
 
 function task_install_deb {
     task install
+    bash ./ext/build-scripts/install-vendored-gems.sh
 }
 
 
@@ -302,6 +307,8 @@ function task_postinst_permissions {
     chmod 770 $app_data
     chown puppet:puppet $projconfdir
     chmod 750 $projconfdir
+    chown puppet:puppet $rundir
+    chmod 0755 $rundir
 }
 
 # Install logrotate (usually el7, fedora 16 and above)
