@@ -9,10 +9,14 @@
 (ns ^{:doc "An EDN reader in clojure"
       :author "Bronsa"}
   clojure.tools.reader.edn
-  (:refer-clojure :exclude [read read-line read-string char default-data-readers])
-  (:use clojure.tools.reader.reader-types
-        [clojure.tools.reader.impl utils commons]
-        [clojure.tools.reader :only [default-data-readers]])
+  (:refer-clojure :exclude [read read-string char default-data-readers])
+  (:require [clojure.tools.reader.reader-types :refer
+             [read-char reader-error unread peek-char indexing-reader?
+              get-line-number get-column-number get-file-name string-push-back-reader]]
+            [clojure.tools.reader.impl.utils :refer
+             [char ex-info? whitespace? numeric? desugar-meta]]
+            [clojure.tools.reader.impl.commons :refer :all]
+            [clojure.tools.reader :refer [default-data-readers]])
   (:import (clojure.lang PersistentHashSet IMeta RT PersistentVector)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -45,8 +49,8 @@
       (reader-error rdr "Invalid leading character: " initch)
 
       :else
-      (loop [sb (doto (StringBuilder.) (.append initch))
-             ch (peek-char rdr)]
+      (loop [sb (StringBuilder.)
+             ch (do (unread rdr initch) initch)]
         (if (or (whitespace? ch)
                 (macro-terminating? ch)
                 (nil? ch))
@@ -115,7 +119,11 @@
   [rdr backslash opts]
   (let [ch (read-char rdr)]
     (if-not (nil? ch)
-      (let [token (read-token rdr ch false)
+      (let [token (if (or (macro-terminating? ch)
+                          (not-constituent? ch)
+                          (whitespace? ch))
+                    (str ch)
+                    (read-token rdr ch false))
             token-len (count token)]
         (cond
 
@@ -136,9 +144,6 @@
              (reader-error rdr "Invalid character constant: \\u" (Integer/toString ic 16))
              c))
 
-         (.startsWith token "x")
-         (read-unicode-char token 1 2 16)
-
          (.startsWith token "o")
          (let [len (dec token-len)]
            (if (> len 3)
@@ -213,10 +218,6 @@
            (if (== -1 (Character/digit (int ch) 16))
              (reader-error rdr "Invalid unicode escape: \\u" ch)
              (read-unicode-char rdr ch 16 4 true)))
-      \x (let [ch (read-char rdr)]
-           (if (== -1 (Character/digit (int ch) 16))
-             (reader-error rdr "Invalid unicode escape: \\x" ch)
-             (read-unicode-char rdr ch 16 2 true)))
       (if (numeric? ch)
         (let [ch (read-unicode-char rdr ch 8 3 false)]
           (if (> (int ch) 0337)
@@ -289,8 +290,8 @@
 
 (defn- read-discard
   [rdr _ opts]
-  (read rdr true nil opts)
-  rdr)
+  (doto rdr
+    (read true nil true)))
 
 (defn- macros [ch]
   (case ch
@@ -363,7 +364,6 @@
             (whitespace? ch) (recur)
             (nil? ch) (if eof-error? (reader-error reader "EOF") eof)
             (number-literal? reader ch) (read-number reader ch opts)
-            (comment-prefix? ch) (do (read-comment reader) (recur))
             :else (let [f (macros ch)]
                     (if f
                       (let [res (f reader ch opts)]
@@ -373,12 +373,23 @@
                       (read-symbol reader ch))))))
        (catch Exception e
          (if (ex-info? e)
-           (throw e)
+           (let [d (ex-data e)]
+             (if (= :reader-exception (:type d))
+               (throw e)
+               (throw (ex-info (.getMessage e)
+                               (merge {:type :reader-exception}
+                                      d
+                                      (if (indexing-reader? reader)
+                                        {:line   (get-line-number reader)
+                                         :column (get-column-number reader)
+                                         :file   (get-file-name reader)}))
+                               e))))
            (throw (ex-info (.getMessage e)
                            (merge {:type :reader-exception}
                                   (if (indexing-reader? reader)
-                                    {:line (get-line-number reader)
-                                     :column (get-column-number reader)}))
+                                    {:line   (get-line-number reader)
+                                     :column (get-column-number reader)
+                                     :file   (get-file-name reader)}))
                            e)))))))
 
 (defn read-string
